@@ -26,7 +26,7 @@
 }
 
 .profitMoffatExactSumPix=function(xpix=c(0,1), ypix=c(0,1), xcen=0, ycen=0, fwhm=3, con=2, ang=0, axrat=1, box=0, rel.tol=1e-3, abs.tol= 1e-10){
-return(cuhre(2, 1, .profitMoffatXY, xcen=xcen, ycen=ycen, fwhm=fwhm, con=con, ang=ang, axrat=axrat, box=box, rel.tol= rel.tol, abs.tol= abs.tol, lower=c(xpix[1],ypix[1]), upper=c(xpix[2],ypix[2]), flags= list(verbose=0))$value)
+return(hcubature(.profitMoffatXY, lowerLimit=c(xpix[1],ypix[1]), upperLimit=c(xpix[2],ypix[2]), xcen=xcen, ycen=ycen, fwhm=fwhm, con=con, ang=ang, axrat=axrat, box=box, tol=rel.tol, absError=abs.tol)$integral)
 }
 
 profitRadialMoffat=function(r=1, mag=15, fwhm=3, con=2, ang=0, axrat=1, box=0){
